@@ -163,10 +163,16 @@ def gather_dataset(ctx,
 @click.command('config', short_help='open the config file in editor')
 @click.option('-f', '--force', is_flag=True,
               help='replaces the config file if one already exists')
+@click.option('--suppress', is_flag=True,
+              help='prevents the config file from being opened in the editor. This may be useful in '
+                   'combination with the force flag to replace an existing configuration silently.')
 @click.pass_context
-def edit_config(ctx, force: bool):
+def edit_config(ctx,
+                force: bool,
+                suppress: bool
+                ) -> None:
     """
-    Opens the config file in the systems default text editor
+    Opens the config file in the systems default text editor.
     """
     config = ctx.obj
 
@@ -192,9 +198,13 @@ def edit_config(ctx, force: bool):
         echo_success(f'created a new config file at "{CONFIG_PATH}"')
         config.load(CONFIG_PATH)
 
-    # Now we simply open the file in the editor
-    echo_info('opening the config file in default editor')
-    open_editor(CONFIG_PATH)
+    if os.path.exists(CONFIG_PATH):
+        echo_info(f'A config path exists @ "{CONFIG_PATH}"')
+
+    # Now we simply open the file in the editor if the "suppress" flag is NOT set
+    if not suppress:
+        echo_info('opening the config file in default editor')
+        open_editor(CONFIG_PATH)
 
 
 @click.command('list', short_help='lists all the datasets available on the file share')
