@@ -9,6 +9,9 @@ project internal dependencies as that would lead to circular dependencies with a
 to access the config...
 """
 import os
+import sys
+import logging
+
 import yaml
 import pathlib
 import platform
@@ -83,6 +86,8 @@ class Config(metaclass=Singleton):
     def __init__(self):
         self.data = {}
         self.path: t.Optional[str] = None
+        self.logger = logging.Logger('MAIN')
+        self.logger.addHandler(logging.StreamHandler(sys.stdout))
 
     def load(self, path: str = CONFIG_PATH):
         self.path = path
