@@ -251,12 +251,12 @@ class MoleculeProcessing(ProcessingBase):
         # core of the graph dict - they always have to be present. All the following code after that is
         # optional additions which can be added to support certain additional features
         graph: tc.GraphDict = {
-            'node_indices': node_indices,
-            'node_attributes': node_attributes,
-            'edge_indices': edge_indices,
-            'edge_attributes': edge_attributes,
-            'graph_attributes': graph_attributes,
-            'graph_labels': graph_labels,
+            'node_indices':         node_indices,
+            'node_attributes':      np.array(node_attributes, dtype=float),
+            'edge_indices':         edge_indices,
+            'edge_attributes':      np.array(edge_attributes, dtype=float),
+            'graph_attributes':     np.array(graph_attributes, dtype=float),
+            'graph_labels':         graph_labels,
         }
 
         # Optionally, if the flag is set, this will apply a conformer on the molecule which will
